Module extra_fields
rawzip
0.4.3
Module extra_
fields
Module Items
Structs
Enums
In crate rawzip
rawzip
Module
extra_
fields
Structs

Extra
Field
Id
A numeric identifier for an extra field in a Zip archive.
Extra
Fields
An iterator over extra field entries in a Zip archive.
Enums

Stack
VecIter